
Malicious intent
-------

**Description:**

Before pushing a code live you should check the software for malicious code in order to 
make sure no developers with evil intent made backdoors or deliberately put in exploits.


**Solution:**

Running your code through a static code analyser or auditing tools could give you a change 
to find malicious peaces of code which could be embedded into the software. 
Also if the new or adjusted functionality is critical then check manually in the form of 
a code review. 
	